--*
--*  version 1.4.6 by Peter Souza IV (@Azilarir)
--*
--*  some code adapted and inspired from `insMobs2Level`
--*    credit: http://www.esoui.com/downloads/info58-insMobs2Level.html
--*  some code adapted and inspired from `Dragon Loot`
--*    credit: http://www.esoui.com/downloads/info18-DragonLoot-SimpleLootAddon.html
--*


-- Load libraries/dependencies
LAM = LibStub:GetLibrary('LibAddonMenu-1.0')


-- Set up some global data
XPN               =   { Lang = { }, Colors = { }, SavedData = { WantSkillID = { }, Window = { }, }, }
XPN.Name          =   "XP Notifier"
XPN.AddonFolder   =   "XPNotifier"
XPN.SaveName      =   "XPNotifier_Data"
XPN.DevDebug      =   false


function XPN.AddonLoaded(eventCode, addOnName)
    if (addOnName ~= XPN.AddonFolder) then return end

	EVENT_MANAGER:RegisterForEvent(XPN.AddonFolder, EVENT_EXPERIENCE_UPDATE,     XPN.GainedXP)
	EVENT_MANAGER:RegisterForEvent(XPN.AddonFolder, EVENT_VETERAN_POINTS_UPDATE, XPN.GainedVP)
	EVENT_MANAGER:RegisterForEvent(XPN.AddonFolder, EVENT_SKILL_XP_UPDATE,       XPN.GainedSkillXP)

	XPN.SavedDefaults =
	{
		ColorText         = { r = 0.706, g = 0.706, b = 0.706 }, -- #B4B4B4
		ColorNumber       = { r = 0.000, g = 1.000, b = 0.000 }, -- #00FF00
		ColorTextTS       = { r = 0.627, g = 0.500, b = 0.753 }, -- #A080C0
		ColorNumberTS     = { r = 0.847, g = 0.125, b = 1.000 }, -- #D720FF
		ColorTextSkill    = { r = 0.753, g = 0.388, b = 0.325 }, -- #C06353
		ColorNumberSkill  = { r = 1.000, g = 0.000, b = 0.000 }, -- #FF0000
		WantXP            = true,
		WantSkillID       = { },
		Window            = { X = 5, Y = 5, Width = 400, Height = 89, UseMode = 0, HideInMenus = true, BackgroundFade = true },
		Language          = "en",
		WantRepeatXP      = true, WantRepeatTS = true, WantRepeatSkill = true,
		GainPrefixXP      = "+", GainPrefixTS = "+", GainPrefixSkill = "+",
		FadeTimer         = 30,
		TrackLevelUps     = true,
	}

	XPN.Player =
	{
		["XP"]            = GetUnitXP           ('player'),
		["Level"]         = GetUnitLevel        ('player'),
		["VeteranRank"]   = GetUnitVeteranRank  ('player'),
		["VeteranPoints"] = GetUnitVeteranPoints('player'),
	}

	XPN.LoadSettings()	
	XPN.Lang.Init()
	XPN.UpdateColors()
	
	XPN.Skills = { List = { } }	
	for iSkillType = 1, GetNumSkillTypes() do
		XPN.Skills[iSkillType] = { }
		for iSkillLine = 1, GetNumSkillLines(iSkillType) do
			XPN.Skills[iSkillType][iSkillLine] = { }
			XPN.Skills[iSkillType][iSkillLine].Name, XPN.Skills[iSkillType][iSkillLine].Level = GetSkillLineInfo(iSkillType, iSkillLine)
			local _, _, temp = GetSkillLineXPInfo(iSkillType, iSkillLine)
			XPN.Skills[iSkillType][iSkillLine].XP = temp			
			XPN.Skills.List[TableLength(XPN.Skills.List) + 1] = { Name = XPN.Skills[iSkillType][iSkillLine].Name, Type = iSkillType, Line = iSkillLine }
		end
	end
	table.sort(XPN.Skills.List, function(a, b) return a.Name < b.Name end)
	
	XPN.SettingsPanel()
	XPN.CreateXPWindow()
	
	-- Need to artificially delay this or else the messages won't show up (too fast)
	zo_callLater(XPN.FullyLoadedUp, 3000)
end


function XPN.FullyLoadedUp()
	XPN.Message(XPN.title .. XPN.Colors.cText .. XPN.Lang.Localization.NowLoadedFor .. XPN.Colors.cNumber .. GetDisplayName() .. "|r" .. XPN.Colors.cText .. ".|r")
end


function XPN.GainedXP(eventCode, unitTag, currentXP, maxXP, reasonCode)
	if (unitTag ~= 'player') then return end
	if (IsUnitVeteran(unitTag)) then return end

	if (XPN.DevDebug) then
		XPN.Message(XPN.title .. "|r|c888888 :: XP gained debug :: " .. eventCode .. ", " .. unitTag .. ", " .. currentXP .. ", " .. maxXP .. ", " .. reasonCode .. "|r")
	end

	local XPEarned = currentXP - XPN.Player.XP
	local currentLevel = GetUnitLevel(unitTag)
	
	if (XPEarned >= 1) then
		if (XPN.SavedData.WantXP) then
			local nextLevelXP = maxXP - currentXP
			local repeatsRequired = math.ceil(nextLevelXP / XPEarned)
			if (currentLevel > XPN.Player.Level) then repeatsRequired = 0 XPN.Player.Level = currentLevel end
			
			local repeatText = ""
			if (XPN.SavedData.WantRepeatXP) then repeatText = " (" .. XPN.Lang.Localization.RepeatToLevelA .. XPN.Colors.cNumber .. PrettyNumberFormatter(repeatsRequired) .. "|r" .. XPN.Colors.cText .. XPN.Lang.Localization.RepeatToLevelB .. ")" end
			
			if (repeatsRequired >= 1) then
				XPN.Message(XPN.Colors.cNumber .. XPN.SavedData.GainPrefixXP .. PrettyNumberFormatter(XPEarned) .. "|r" .. XPN.Colors.cText .. " XP" .. repeatText .. "|r")
			else
				XPN.Message(XPN.Colors.cNumber .. XPN.SavedData.GainPrefixXP .. PrettyNumberFormatter(XPEarned) .. "|r" .. XPN.Colors.cText .. " XP (" .. XPN.Colors.cNumber .. XPN.Lang.Localization.NewLevel .. XPN.Player.Level .. "!|r" .. XPN.Colors.cText .. ")|r")
			end
		elseif ((XPN.SavedData.TrackLevelUps) and (currentLevel > XPN.Player.Level)) then
			XPN.Player.Level = currentLevel
		
			XPN.Message(XPN.Colors.cText .. XPN.Lang.Localization.Level .. ": " .. XPN.Colors.cNumber .. XPN.Lang.Localization.NewLevel .. XPN.Player.Level .. "!|r")
		end
	end
	
	XPN.Player.XP = currentXP	
end


function XPN.GainedVP(eventCode, unitTag, currentXP, maxXP, reasonCode)
	if (unitTag ~= 'player') then return end

	if (XPN.DevDebug) then
		XPN.Message(XPN.title .. "|r|c888888 :: VP gained debug :: " .. eventCode .. ", " .. unitTag .. ", " .. currentXP .. ", " .. maxXP .. ", " .. reasonCode .. "|r")
	end

	local XPEarned = currentXP - XPN.Player.VeteranPoints
	local currentRank = GetUnitVeteranRank(unitTag)
	
	if (XPEarned >= 1) then
		if (XPN.SavedData.WantXP) then
			local nextLevelXP = maxXP - currentXP
			local repeatsRequired = math.ceil(nextLevelXP / XPEarned)
			if (currentRank > XPN.Player.VeteranRank) then repeatsRequired = 0 XPN.Player.VeteranRank = currentRank end
			
			local repeatText = ""
			if (XPN.SavedData.WantRepeatXP) then repeatText = " (" .. XPN.Lang.Localization.RepeatToLevelA .. XPN.Colors.cNumber .. PrettyNumberFormatter(repeatsRequired) .. "|r" .. XPN.Colors.cText .. XPN.Lang.Localization.RepeatToLevelB .. ")" end

			if (repeatsRequired >= 1) then
				XPN.Message(XPN.Colors.cNumber .. XPN.SavedData.GainPrefixXP .. PrettyNumberFormatter(XPEarned) .. " " .. "VP |r" .. XPN.Colors.cText .. repeatText .. "|r")
			else
				XPN.Message(XPN.Colors.cNumber .. XPN.SavedData.GainPrefixXP .. PrettyNumberFormatter(XPEarned) .. " " .. "VP |r" .. XPN.Colors.cText .. " (" .. XPN.Colors.cNumber .. XPN.Lang.Localization.NewLevelVP .. XPN.Player.VeteranRank .. "!|r" .. XPN.Colors.cText .. ")|r")
			end
		elseif ((XPN.SavedData.TrackLevelUps) and (currentRank > XPN.Player.VeteranRank)) then
			XPN.Player.VeteranRank = currentRank
			
			XPN.Message(XPN.Colors.cText .. XPN.Lang.Localization.Veteran .. ": " .. XPN.Colors.cNumber .. XPN.Lang.Localization.NewLevelVP .. XPN.Player.VeteranRank .. "!|r")
		end
	end
	
	XPN.Player.VeteranPoints = currentXP
end


function XPN.GainedSkillXP(eventID, skillType, skillLine, lastRankXP, nextRankXP, currentXP)
	local skillName, currentLevel = GetSkillLineInfo(skillType, skillLine)

	XPN.AddSkillIfNotExist(skillName, skillType, skillLine)
	
	if (XPN.DevDebug) then
		if (skillName == nil) then skillName = '(nil)' end
		if (currentLevel == nil) then currentLevel = '(nil)' end
		if (XPN.Skills[skillType][skillLine].Level == nil) then XPN.Skills[skillType][skillLine].Level = currentLevel end
		if (eventID == nil) then eventID = '(nil)' end
		if (skillLine == nil) then skillLine = '(nil)' end
		if (lastRankXP == nil) then lastRankXP = '(nil)' end
		if (nextRankXP == nil) then nextRankXP = '(nil)' end
		if (currentXP == nil) then currentXP = '(nil)' end
		XPN.Message(XPN.title .. "|r|c888888 :: skill XP gained debug :: " .. CleanName(skillName) .. ", " .. currentLevel .. ", " .. XPN.Skills[skillType][skillLine].Level .. ", " .. eventID .. ", " .. skillType .. ", " .. skillLine .. ", " .. lastRankXP .. ", " .. nextRankXP .. ", " .. currentXP .. "|r")
	end

	if (XPN.WantSkill(skillName)) then
		local XPGained = currentXP - XPN.Skills[skillType][skillLine].XP
		local nextLevelXP = nextRankXP - lastRankXP
		local XPCurrent = currentXP - lastRankXP
		local nextLevelNeededXP = nextLevelXP - XPCurrent

		skillName = CleanName(skillName)
		
		if (XPGained >= 1) then
			local repeatText = ""
			local repeatsRequired = math.ceil(nextLevelNeededXP / XPGained)
			if (currentLevel > XPN.Skills[skillType][skillLine].Level) then repeatsRequired = 0 XPN.Skills[skillType][skillLine].Level = currentLevel end
			
			if (skillType == SKILL_TYPE_TRADESKILL) then
				if (XPN.SavedData.WantRepeatTS) then repeatText = " (" .. XPN.Lang.Localization.RepeatToLevelA .. XPN.Colors.cNumberTS .. PrettyNumberFormatter(repeatsRequired) .. "|r" .. XPN.Colors.cTextTS .. XPN.Lang.Localization.RepeatToLevelB .. ")" end
		
				if (repeatsRequired >= 1) then
					XPN.Message(XPN.Colors.cNumberTS .. XPN.SavedData.GainPrefixTS .. PrettyNumberFormatter(XPGained) .. " " .. skillName .. "|r" .. XPN.Colors.cTextTS .. " XP" .. repeatText .. "|r")
				else
					XPN.Message(XPN.Colors.cNumberTS .. XPN.SavedData.GainPrefixTS .. PrettyNumberFormatter(XPGained) .. " " .. skillName .. "|r" .. XPN.Colors.cTextTS .. " XP (" .. XPN.Colors.cNumberTS .. XPN.Lang.Localization.NewLevelTS .. XPN.Skills[skillType][skillLine].Level .. "!|r" .. XPN.Colors.cTextTS .. ")|r")
				end
			else
				if (XPN.SavedData.WantRepeatSkill) then repeatText = " (" .. XPN.Lang.Localization.RepeatToLevelA .. XPN.Colors.cNumberSkill .. PrettyNumberFormatter(repeatsRequired) .. "|r" .. XPN.Colors.cTextSkill .. XPN.Lang.Localization.RepeatToLevelB .. ")" end
			
				if (repeatsRequired >= 1) then
					XPN.Message(XPN.Colors.cNumberSkill .. XPN.SavedData.GainPrefixSkill .. PrettyNumberFormatter(XPGained) .. " " .. skillName .. "|r" .. XPN.Colors.cTextSkill .. " XP" .. repeatText .. "|r")
				else
					XPN.Message(XPN.Colors.cNumberSkill .. XPN.SavedData.GainPrefixSkill .. PrettyNumberFormatter(XPGained) .. " " .. skillName .. "|r" .. XPN.Colors.cTextSkill .. " XP (" .. XPN.Colors.cNumberSkill .. XPN.Lang.Localization.NewLevelSkill .. XPN.Skills[skillType][skillLine].Level .. "!|r" .. XPN.Colors.cTextSkill .. ")|r")
				end
			end
		end
	elseif (XPN.SavedData.TrackLevelUps) then
		if (currentLevel > XPN.Skills[skillType][skillLine].Level) then
			XPN.Skills[skillType][skillLine].Level = currentLevel
			
			if (skillType == SKILL_TYPE_TRADESKILL) then
				XPN.Message(XPN.Colors.cTextTS .. CleanName(skillName) .. ":|r " .. XPN.Colors.cNumberTS .. XPN.Lang.Localization.NewLevelTS .. XPN.Skills[skillType][skillLine].Level .. "!|r")
			else
				XPN.Message(XPN.Colors.cTextSkill .. CleanName(skillName) .. ":|r " .. XPN.Colors.cNumberSkill .. XPN.Lang.Localization.NewLevelSkill .. XPN.Skills[skillType][skillLine].Level .. "!|r")
			end
		end
		
	end
	
	XPN.Skills[skillType][skillLine].XP = currentXP
end


-- Hook the add-on into the ESO event notification system
EVENT_MANAGER:RegisterForEvent(XPN.AddonFolder, EVENT_ADD_ON_LOADED, XPN.AddonLoaded)
