function XPN.LoadSettings()
	XPN.SavedData = ZO_SavedVars:New(XPN.SaveName, 1, nil, XPN.SavedDefaults)
end


function XPN.UpdateColors()
	XPN.Colors.cText        = "|c" .. ConvertColorToHex(XPN.SavedData.ColorText)
	XPN.Colors.cNumber      = "|c" .. ConvertColorToHex(XPN.SavedData.ColorNumber)
	XPN.Colors.cTextTS      = "|c" .. ConvertColorToHex(XPN.SavedData.ColorTextTS)
	XPN.Colors.cNumberTS    = "|c" .. ConvertColorToHex(XPN.SavedData.ColorNumberTS)
	XPN.Colors.cTextSkill   = "|c" .. ConvertColorToHex(XPN.SavedData.ColorTextSkill)
	XPN.Colors.cNumberSkill = "|c" .. ConvertColorToHex(XPN.SavedData.ColorNumberSkill)
	
	XPN.title = XPN.Colors.cNumber .. "XP Notifier|r"
end


function XPN.SkillByName(skillName)
	for i = 1, TableLength(XPN.Skills.List) do
		if (XPN.Skills.List[i].Name == skillName) then return XPN.Skills.List[i] end
		if (CleanName(XPN.Skills.List[i].Name) == CleanName(skillName)) then return XPN.Skills.List[i] end
	end
	
	return nil
end


function XPN.AddSkillIfNotExist(skillName, skillType, skillLine)
	if (XPN.Skills[skillType] == nil) then XPN.Skills[skillType] = { } end
	if (XPN.Skills[skillType][skillLine] == nil) then XPN.Skills[skillType][skillLine] = { } else return end

	XPN.Skills[skillType][skillLine].Name, XPN.Skills[skillType][skillLine].Level = GetSkillLineInfo(skillType, skillLine)
	local _, _, temp = GetSkillLineXPInfo(skillType, skillLine)
	XPN.Skills[skillType][skillLine].XP = temp
	XPN.Skills.List[TableLength(XPN.Skills.List) + 1] = { Name = XPN.Skills[skillType][skillLine].Name, Type = skillType, Line = skillLine }

	XPN.Message("|cFF0000" .. XPN.Lang.Localization.ReloadUIForNewSkill .. "|r")
end


function XPN.WantSkill(skillName)
	if (XPN.SavedData.WantSkillID[skillName] ~= nil) then
		return XPN.SavedData.WantSkillID[skillName]
	end
	
	local skillInfo = XPN.SkillByName(skillName)
	
	if (skillInfo == nil) then return false end	
	if (skillInfo.Type == 8) then return true end	
	return false
end


function XPN.SettingsPanel()
	if (XPN.Lang.CurrentLanguage() == "French") then
		XPN.SettingsPanelFrench()
	elseif (XPN.Lang.CurrentLanguage() == "German") then
		XPN.SettingsPanelGerman()
	else
		XPN.SettingsPanelEnglish()
	end	
end


function XPN.SettingsPanelEnglish()
	XPN.SettingsPanel = LAM:CreateControlPanel('XPN_Config', XPN.Name)

	LAM:AddHeader(XPN.SettingsPanel, 'XPN_Config_Header_General', '|cCAB222General|r')
	
	LAM:AddDropdown(
		XPN.SettingsPanel,
		'XPN_Config_General_Language',
		'Language',
		'',
		{ 'Deutsch (German)', 'English', 'Français (French)', },
		function() return "English" end,
		function(val)
			if (val == "Deutsch (German)") then XPN.SavedData.Language = "de" end
			if (val == "English") then return end
			if (val == "Français (French)") then XPN.SavedData.Language = "fr" end
			ReloadUI()
		end,
		true,
		'Adjusting the language will reload your UI immediately.'
	)

	LAM:AddDropdown(
		XPN.SettingsPanel,
		"XPN_Config_General_WindowMode",
		"Messages should be sent to...",
		"Choose where experience gain messages should be sent to.",
		{
			"your chat window",
			"a new window",
			"both"
		},
		function()
			if (XPN.SavedData.Window.UseMode == 1) then return "a new window" end
			if (XPN.SavedData.Window.UseMode == 2) then return "both" end
			return "your chat window"
		end,
		function(val)
			if (val == "your chat window") then XPN.SavedData.Window.UseMode = 0 end
			if (val == "a new window") then XPN.SavedData.Window.UseMode = 1 end
			if (val == "both") then XPN.SavedData.Window.UseMode = 2 end
			XPN.ShowWindowPerSettings()
		end
	)
	
	LAM:AddCheckbox(
		XPN.SettingsPanel,
		'XPN_Config_General_WindowBGFade',
		'Automatically fade out the background',
		'Enable this to automatically fade out the background of the XP Notifier window when the mouse cursor is not hovering over the window.  This setting only applies if you are sending experience gain notification messages to a new window (or to both a new window and the chat window).',
		function() return XPN.SavedData.Window.BackgroundFade end,
		function(val) XPN.SavedData.Window.BackgroundFade = val XPN.WindowBackgroundFadePerSettings() end
	)
	
	LAM:AddSlider(
		XPN.SettingsPanel,
		'XPN_Config_Notifier_FadeTimer',
		'Fade timeout',
		'How many seconds should it take for messages in the XP Notifier window to fade away after your last experience gain?',
		1, 600, 1,
		function() return XPN.SavedData.FadeTimer end,
		function(val) XPN.SavedData.FadeTimer = val end
	)
	
	LAM:AddCheckbox(
		XPN.SettingsPanel,
		'XPN_Config_General_WindowHide',
		'Hide the window in settings and menus',
		'Enable this to hide the XP Notifier window when you are in settings and menus.  This setting only applies if you are sending experience gain notification messages to a new window (or to both a new window and the chat window).',
		function() return XPN.SavedData.Window.HideInMenus end,
		function(val) XPN.SavedData.Window.HideInMenus = val XPN.InterfaceUpdate() end
	)
	
	LAM:AddCheckbox(
		XPN.SettingsPanel,
		'XPN_Config_General_TrackLevelUps',
		'Always notify level gains',
		'Enable this option to notify level-ups and skill-ups even when that type of experience isn\'t set to notify.',
		function() return XPN.SavedData.TrackLevelUps end,
		function(val) XPN.SavedData.TrackLevelUps = val end
	)
		
	LAM:AddDescription(XPN.SettingsPanel, 'WindowHideDesc', 'Please note: if you use any add-ons that hide the compass while playing, the above setting will not work (the XP Notifier window will always be hidden).  Due to a limited add-on API, interface menu/settings detection is checking the visibility of the game compass.  If you do not use any add-ons that hide the compass during gameplay or are not using the separate XP Notifier window, you can ignore this message.', nil)
	
	LAM:AddDescription(XPN.SettingsPanel, 'spacer3', '\r\n', nil)

	LAM:AddHeader(XPN.SettingsPanel, 'XPN_Config_Header_CharacterXP', '|cCAB222Character XP|r')

	LAM:AddCheckbox(
		XPN.SettingsPanel,
		'XPN_Config_Notifier_WantXP',
		'Notify on character XP gain',
		'Enable this to receive messages in the chat window whenever you receive character experience.',
		function() return XPN.SavedData.WantXP end,
		function(val) XPN.SavedData.WantXP = val end
	)
	
	LAM:AddCheckbox(
		XPN.SettingsPanel,
		'XPN_Config_Notifier_WantRepeatXP',
		'Show repeat count',
		'Shows how many repetitions it would take of the last XP gain event to level up.',
		function() return XPN.SavedData.WantRepeatXP end,
		function(val) XPN.SavedData.WantRepeatXP = val end
	)
	
	LAM:AddEditBox(
		XPN.SettingsPanel,
		'XPN_Config_Notifier_GainPrefixXP',
		'Notifier prefix',
		'',
		false,
		function() return XPN.SavedData.GainPrefixXP end,
		function(val) XPN.SavedData.GainPrefixXP = val end
	)
	
	LAM:AddColorPicker(
		XPN.SettingsPanel,
		'XPN_Config_Text',
		'Text color',
		'Set the color for general text in the character XP notifier.',
		function() return XPN.SavedData.ColorText.r, XPN.SavedData.ColorText.g, XPN.SavedData.ColorText.b end,
		function(r, g, b) XPN.SavedData.ColorText = {r = r, g = g, b = b} XPN.UpdateColors() end
	)
	
	LAM:AddColorPicker(
		XPN.SettingsPanel,
		'XPN_Config_Numbers',
		'Number color',
		'Set the color for numbers in the character XP notifier.',
		function() return XPN.SavedData.ColorNumber.r, XPN.SavedData.ColorNumber.g, XPN.SavedData.ColorNumber.b end,
		function(r, g, b) XPN.SavedData.ColorNumber = {r = r, g = g, b = b} XPN.UpdateColors() end
	)

	LAM:AddButton(
		XPN.SettingsPanel,
		'XPN_Config_TestXP',
		'Test Settings',
		'Click this button to test your color preferences.\r\n\r\nMake sure you have expanded your chat window so you can see the test message.',
		function() XPN.Message(XPN.Colors.cText .. "This is a |r" .. XPN.Colors.cNumber .. "test message|r" .. XPN.Colors.cText .. " from XP Notifier.|r") end,
		true,
		'Don\'t forget to expand your chat window so you can see test messages.'
	)
	
	LAM:AddDescription(XPN.SettingsPanel, 'spacer1', '\r\n', nil)
	
	LAM:AddHeader(XPN.SettingsPanel, 'XPN_Config_Header_TradeskillXP', '|cCAB222Tradeskills|r')

	LAM:AddCheckbox(
		XPN.SettingsPanel,
		'XPN_Config_Notifier_WantRepeatTS',
		'Show repeat count',
		'Shows how many repetitions it would take of the last tradeskill XP gain event to level up.',
		function() return XPN.SavedData.WantRepeatTS end,
		function(val) XPN.SavedData.WantRepeatTS = val end
	)	
	
	LAM:AddEditBox(
		XPN.SettingsPanel,
		'XPN_Config_Notifier_GainPrefixTS',
		'Notifier prefix',
		'',
		false,
		function() return XPN.SavedData.GainPrefixTS end,
		function(val) XPN.SavedData.GainPrefixTS = val end
	)
	
	for i = 1, TableLength(XPN.Skills.List) do
		if (XPN.Skills.List[i].Type == 8) then
			LAM:AddCheckbox(
				XPN.SettingsPanel,
				'XPN_Config_Notifier_Want' .. XPN.Skills.List[i].Name,
				CleanName(XPN.Skills.List[i].Name),
				'Enable this to receive messages in the chat window whenever you receive ' .. CleanName(XPN.Skills.List[i].Name) .. ' experience.',
				function() return XPN.WantSkill(XPN.Skills.List[i].Name) end,
				function(val) XPN.SavedData.WantSkillID[XPN.Skills.List[i].Name] = val end
			)
		end
	end

	LAM:AddColorPicker(
		XPN.SettingsPanel,
		'XPN_Config_TextTS',
		'Text color',
		'Set the color for general text in the tradeskill notifiers.',
		function() return XPN.SavedData.ColorTextTS.r, XPN.SavedData.ColorTextTS.g, XPN.SavedData.ColorTextTS.b end,
		function(r, g, b) XPN.SavedData.ColorTextTS = {r = r, g = g, b = b} XPN.UpdateColors() end
	)
	
	LAM:AddColorPicker(
		XPN.SettingsPanel,
		'XPN_Config_NumbersTS',
		'Number color',
		'Set the color for numbers in the tradeskill notifiers.',
		function() return XPN.SavedData.ColorNumberTS.r, XPN.SavedData.ColorNumberTS.g, XPN.SavedData.ColorNumberTS.b end,
		function(r, g, b) XPN.SavedData.ColorNumberTS = {r = r, g = g, b = b} XPN.UpdateColors() end
	)
	
	LAM:AddButton(
		XPN.SettingsPanel,
		'XPN_Config_TestTS',
		'Test Settings',
		'Click this button to test your color preferences.\r\n\r\nMake sure you have expanded your chat window so you can see the test message.',
		function() XPN.Message(XPN.Colors.cTextTS .. "This is a |r" .. XPN.Colors.cNumberTS .. "test message|r" .. XPN.Colors.cTextTS .. " from XP Notifier.|r") end,
		true,
		'Don\'t forget to expand your chat window so you can see test messages.'
	)
	
	LAM:AddDescription(XPN.SettingsPanel, 'spacer2', '\r\n', nil)
	
	LAM:AddHeader(XPN.SettingsPanel, 'XPN_Config_Header_OtherSkillXP', '|cCAB222Other Skills|r')

	LAM:AddCheckbox(
		XPN.SettingsPanel,
		'XPN_Config_Notifier_WantRepeatSkill',
		'Show repeat count',
		'Shows how many repetitions it would take of the last skill XP gain event to level up.',
		function() return XPN.SavedData.WantRepeatSkill end,
		function(val) XPN.SavedData.WantRepeatSkill = val end
	)
	
	LAM:AddEditBox(
		XPN.SettingsPanel,
		'XPN_Config_Notifier_GainPrefixSkill',
		'Notifier prefix',
		'',
		false,
		function() return XPN.SavedData.GainPrefixSkill end,
		function(val) XPN.SavedData.GainPrefixSkill = val end
	)
	
	for i = 1, TableLength(XPN.Skills.List) do
		if (XPN.Skills.List[i].Type ~= 8) then
			LAM:AddCheckbox(
				XPN.SettingsPanel,
				'XPN_Config_Notifier_Want' .. XPN.Skills.List[i].Name,
				CleanName(XPN.Skills.List[i].Name),
				'Enable this to receive messages in the chat window whenever you receive ' .. CleanName(XPN.Skills.List[i].Name) .. ' experience.',
				function() return XPN.WantSkill(XPN.Skills.List[i].Name) end,
				function(val) XPN.SavedData.WantSkillID[XPN.Skills.List[i].Name] = val end
			)
		end
	end

	LAM:AddColorPicker(
		XPN.SettingsPanel,
		'XPN_Config_TextSkill',
		'Text color',
		'Set the color for general text in the skill notifiers.',
		function() return XPN.SavedData.ColorTextSkill.r, XPN.SavedData.ColorTextSkill.g, XPN.SavedData.ColorTextSkill.b end,
		function(r, g, b) XPN.SavedData.ColorTextSkill = {r = r, g = g, b = b} XPN.UpdateColors() end
	)
	
	LAM:AddColorPicker(
		XPN.SettingsPanel,
		'XPN_Config_NumbersSkill',
		'Number color',
		'Set the color for numbers in the skill notifiers.',
		function() return XPN.SavedData.ColorNumberSkill.r, XPN.SavedData.ColorNumberSkill.g, XPN.SavedData.ColorNumberSkill.b end,
		function(r, g, b) XPN.SavedData.ColorNumberSkill = {r = r, g = g, b = b} XPN.UpdateColors() end
	)
	
	LAM:AddButton(
		XPN.SettingsPanel,
		'XPN_Config_TestSkill',
		'Test Settings',
		'Click this button to test your color preferences.\r\n\r\nMake sure you have expanded your chat window so you can see the test message.',
		function() XPN.Message(XPN.Colors.cTextSkill .. "This is a |r" .. XPN.Colors.cNumberSkill .. "test message|r" .. XPN.Colors.cTextSkill .. " from XP Notifier.|r") end,
		true,
		'Don\'t forget to expand your chat window so you can see test messages.'
	)
	
	LAM:AddDescription(XPN.SettingsPanel, 'spacer4', '\r\n', nil)
	
	LAM:AddHeader(XPN.SettingsPanel, 'XPN_Config_Header_Debug', '|cCAB222Debug|r')
	
	LAM:AddCheckbox(
		XPN.SettingsPanel,
		'XPN_Config_General_DevDebug',
		'Developer debug messages',
		'Enable this for assisting the author with troubleshooting, etc.',
		function() return XPN.DevDebug end,
		function(val) XPN.DevDebug = val end
	)
end


function XPN.SettingsPanelFrench()
	XPN.SettingsPanel = LAM:CreateControlPanel('XPN_Config', XPN.Name)

	LAM:AddHeader(XPN.SettingsPanel, 'XPN_Config_Header_General', '|cCAB222Général|r')
	
	LAM:AddDropdown(
		XPN.SettingsPanel,
		'XPN_Config_General_Language',
		'Langue',
		'',
		{ 'Deutsch (Allemand)', 'English (Anglais)', 'Français', },
		function() return "Français" end,
		function(val)
			if (val == "Deutsch (Allemand)") then XPN.SavedData.Language = "de" end
			if (val == "English (Anglais)") then XPN.SavedData.Language = "en" end
			if (val == "Français") then return end
			ReloadUI()
		end,
		true,
		'Changer cet option rechargera votre interface.'
	)
	
	LAM:AddDropdown(
		XPN.SettingsPanel,
		"XPN_Config_General_WindowMode",
		"Les messages devraient être envoyés à...",
		"Choisissez où les messages de gain d'expérience devraient être envoyés à.",
		{
			"votre fenêtre de chat",
			"une nouvelle fenêtre",
			"tous les deux"
		},
		function()
			if (XPN.SavedData.Window.UseMode == 1) then return "une nouvelle fenêtre" end
			if (XPN.SavedData.Window.UseMode == 2) then return "tous les deux" end
			return "votre fenêtre de chat"
		end,
		function(val)
			if (val == "votre fenêtre de chat") then XPN.SavedData.Window.UseMode = 0 end
			if (val == "une nouvelle fenêtre") then XPN.SavedData.Window.UseMode = 1 end
			if (val == "tous les deux") then XPN.SavedData.Window.UseMode = 2 end
			XPN.ShowWindowPerSettings()
		end
	)
	
	LAM:AddCheckbox(
		XPN.SettingsPanel,
		'XPN_Config_General_WindowBGFade',
		'S\'estomper automatiquement le fond',
		'Activez cette option pour s\'effacer automatiquement le fond de la fenêtre XP Notifier lorsque la souris n\'est pas planait au-dessus de la fenêtre.  Ce paramètre s\'applique uniquement si vous envoyez le gain de l\'expérience des messages de notification dans une nouvelle fenêtre (ou à la fois une nouvelle fenêtre et la fenêtre de chat).',
		function() return XPN.SavedData.Window.BackgroundFade end,
		function(val) XPN.SavedData.Window.BackgroundFade = val XPN.WindowBackgroundFadePerSettings() end
	)
	
	LAM:AddSlider(
		XPN.SettingsPanel,
		'XPN_Config_Notifier_FadeTimer',
		'Fondu de timeout',
		'Combien de secondes il devrait prendre pour les messages dans la fenêtre de XPNotifier à s\'estomper après votre dernière expérience de gain?',
		1, 600, 1,
		function() return XPN.SavedData.FadeTimer end,
		function(val) XPN.SavedData.FadeTimer = val XPN.FadeWindowSettingUpdate() end
	)
	
	LAM:AddCheckbox(
		XPN.SettingsPanel,
		'XPN_Config_General_WindowHide',
		'Cacher pendant les menus',
		'Activez cette option pour masquer la fenêtre XP Notifier quand vous êtes dans les paramètres et les menu.  Ce paramètre s\'applique uniquement si vous envoyez le gain de l\'expérience des messages de notification dans une nouvelle fenêtre (ou à la fois une nouvelle fenêtre et la fenêtre de chat).',
		function() return XPN.SavedData.Window.HideInMenus end,
		function(val) XPN.SavedData.Window.HideInMenus = val XPN.InterfaceUpdate() end
	)
		
	LAM:AddCheckbox(
		XPN.SettingsPanel,
		'XPN_Config_General_TrackLevelUps',
		'Toujours notifier des gains de niveau',
		'',
		function() return XPN.SavedData.TrackLevelUps end,
		function(val) XPN.SavedData.TrackLevelUps = val end
	)

	--LAM:AddDescription(XPN.SettingsPanel, 'WindowHideDesc', 'Please note: if you use any add-ons that hide the compass while playing, the above setting will not work (the XP Notifier window will always be hidden).  Due to a limited add-on API, interface menu/settings detection is checking the visibility of the game compass.  If you do not use any add-ons that hide the compass during gameplay or are not using the separate XP Notifier window, you can ignore this message.', nil)
	
	LAM:AddDescription(XPN.SettingsPanel, 'spacer3', '\r\n', nil)

	LAM:AddHeader(XPN.SettingsPanel, 'XPN_Config_Header_CharacterXP', '|cCAB222XP de Caractère|r')

	LAM:AddCheckbox(
		XPN.SettingsPanel,
		'XPN_Config_Notifier_WantXP',
		'XP de caractère',
		'Activez cette option pour recevoir des messages dans la fenêtre de discussion lorsque vous recevez expérience de caractère.',
		function() return XPN.SavedData.WantXP end,
		function(val) XPN.SavedData.WantXP = val end
	)
	
	LAM:AddCheckbox(
		XPN.SettingsPanel,
		'XPN_Config_Notifier_WantRepeatXP',
		'Nombre spectacle de répétition',
		'', --'Shows how many repetitions it would take of the last XP gain event to level up.',
		function() return XPN.SavedData.WantRepeatXP end,
		function(val) XPN.SavedData.WantRepeatXP = val end
	)

	LAM:AddEditBox(
		XPN.SettingsPanel,
		'XPN_Config_Notifier_GainPrefixXP',
		'Préfixe de notification',
		'',
		false,
		function() return XPN.SavedData.GainPrefixXP end,
		function(val) XPN.SavedData.GainPrefixXP = val end
	)

	LAM:AddColorPicker(
		XPN.SettingsPanel,
		'XPN_Config_Text',
		'Couleur du texte',
		'Définir la couleur de texte général dans le caractère expérience notifiant.',
		function() return XPN.SavedData.ColorText.r, XPN.SavedData.ColorText.g, XPN.SavedData.ColorText.b end,
		function(r, g, b) XPN.SavedData.ColorText = {r = r, g = g, b = b} XPN.UpdateColors() end
	)
	
	LAM:AddColorPicker(
		XPN.SettingsPanel,
		'XPN_Config_Numbers',
		'Couleur du nombre',
		'Définir la couleur des numéros dans le caractère expérience notifiant.',
		function() return XPN.SavedData.ColorNumber.r, XPN.SavedData.ColorNumber.g, XPN.SavedData.ColorNumber.b end,
		function(r, g, b) XPN.SavedData.ColorNumber = {r = r, g = g, b = b} XPN.UpdateColors() end
	)

	LAM:AddButton(
		XPN.SettingsPanel,
		'XPN_Config_TestXP',
		'Vérifier vos Préférences',
		'Cliquez sur ce bouton pour vérifier vos préférences de couleur.\r\n\r\nAssurez-vous que vous avez élargi votre fenêtre de chat ainsi vous pouvez voir le message de test.',
		function() XPN.Message(XPN.Colors.cText .. "Ceci est un |r" .. XPN.Colors.cNumber .. "message de test|r" .. XPN.Colors.cText .. " de XP Notifier.|r") end,
		true,
		'N\'oubliez pas d\'agrandir votre fenêtre de chat afin que vous puissiez voir les messages de test.'
	)
	
	LAM:AddDescription(XPN.SettingsPanel, 'spacer1', '\r\n', nil)
	
	LAM:AddHeader(XPN.SettingsPanel, 'XPN_Config_Header_TradeskillXP', '|cCAB222Artisanats|r')

	LAM:AddCheckbox(
		XPN.SettingsPanel,
		'XPN_Config_Notifier_WantRepeatTS',
		'Nombre spectacle de répétition',
		'', --'Shows how many repetitions it would take of the last tradeskill XP gain event to level up.',
		function() return XPN.SavedData.WantRepeatTS end,
		function(val) XPN.SavedData.WantRepeatTS = val end
	)
	
	LAM:AddEditBox(
		XPN.SettingsPanel,
		'XPN_Config_Notifier_GainPrefixTS',
		'Préfixe de notification',
		'',
		false,
		function() return XPN.SavedData.GainPrefixTS end,
		function(val) XPN.SavedData.GainPrefixTS = val end
	)
	
	for i = 1, TableLength(XPN.Skills.List) do
		if (XPN.Skills.List[i].Type == 8) then
			LAM:AddCheckbox(
				XPN.SettingsPanel,
				'XPN_Config_Notifier_Want' .. XPN.Skills.List[i].Name,
				CleanName(XPN.Skills.List[i].Name),
				'Activez cette option pour recevoir des messages dans la fenêtre de discussion lorsque vous recevez expérience de ' .. CleanName(XPN.Skills.List[i].Name) .. '.',
				function() return XPN.WantSkill(XPN.Skills.List[i].Name) end,
				function(val) XPN.SavedData.WantSkillID[XPN.Skills.List[i].Name] = val end
			)
		end
	end

	LAM:AddColorPicker(
		XPN.SettingsPanel,
		'XPN_Config_TextTS',
		'Couleur du texte',
		'',
		function() return XPN.SavedData.ColorTextTS.r, XPN.SavedData.ColorTextTS.g, XPN.SavedData.ColorTextTS.b end,
		function(r, g, b) XPN.SavedData.ColorTextTS = {r = r, g = g, b = b} XPN.UpdateColors() end
	)
	
	LAM:AddColorPicker(
		XPN.SettingsPanel,
		'XPN_Config_NumbersTS',
		'Couleur du nombre',
		'',
		function() return XPN.SavedData.ColorNumberTS.r, XPN.SavedData.ColorNumberTS.g, XPN.SavedData.ColorNumberTS.b end,
		function(r, g, b) XPN.SavedData.ColorNumberTS = {r = r, g = g, b = b} XPN.UpdateColors() end
	)
	
	LAM:AddButton(
		XPN.SettingsPanel,
		'XPN_Config_TestTS',
		'Vérifier vos Préférences',
		'Cliquez sur ce bouton pour vérifier vos préférences de couleur.\r\n\r\nAssurez-vous que vous avez élargi votre fenêtre de chat ainsi vous pouvez voir le message de test.',
		function() XPN.Message(XPN.Colors.cTextTS .. "Ceci est un |r" .. XPN.Colors.cNumberTS .. "message de test|r" .. XPN.Colors.cTextTS .. " de XP Notifier.|r") end,
		true,
		'N\'oubliez pas d\'agrandir votre fenêtre de chat afin que vous puissiez voir les messages de test.'
	)
	
	LAM:AddDescription(XPN.SettingsPanel, 'spacer2', '\r\n', nil)
	
	LAM:AddHeader(XPN.SettingsPanel, 'XPN_Config_Header_OtherSkillXP', '|cCAB222Autres Compétences|r')

	LAM:AddCheckbox(
		XPN.SettingsPanel,
		'XPN_Config_Notifier_WantRepeatSkill',
		'Nombre spectacle de répétition',
		'', --'Shows how many repetitions it would take of the last skill XP gain event to level up.',
		function() return XPN.SavedData.WantRepeatSkill end,
		function(val) XPN.SavedData.WantRepeatSkill = val end
	)	
	
	LAM:AddEditBox(
		XPN.SettingsPanel,
		'XPN_Config_Notifier_GainPrefixSkill',
		'Préfixe de notification',
		'',
		false,
		function() return XPN.SavedData.GainPrefixSkill end,
		function(val) XPN.SavedData.GainPrefixSkill = val end
	)
	
	for i = 1, TableLength(XPN.Skills.List) do
		if (XPN.Skills.List[i].Type ~= 8) then
			LAM:AddCheckbox(
				XPN.SettingsPanel,
				'XPN_Config_Notifier_Want' .. XPN.Skills.List[i].Name,
				CleanName(XPN.Skills.List[i].Name),
				'Activez cette option pour recevoir des messages dans la fenêtre de discussion lorsque vous recevez expérience de ' .. CleanName(XPN.Skills.List[i].Name) .. '.',
				function() return XPN.WantSkill(XPN.Skills.List[i].Name) end,
				function(val) XPN.SavedData.WantSkillID[XPN.Skills.List[i].Name] = val end
			)
		end
	end

	LAM:AddColorPicker(
		XPN.SettingsPanel,
		'XPN_Config_TextSkill',
		'Couleur du texte',
		'',
		function() return XPN.SavedData.ColorTextSkill.r, XPN.SavedData.ColorTextSkill.g, XPN.SavedData.ColorTextSkill.b end,
		function(r, g, b) XPN.SavedData.ColorTextSkill = {r = r, g = g, b = b} XPN.UpdateColors() end
	)
	
	LAM:AddColorPicker(
		XPN.SettingsPanel,
		'XPN_Config_NumbersSkill',
		'Couleur du nombre',
		'',
		function() return XPN.SavedData.ColorNumberSkill.r, XPN.SavedData.ColorNumberSkill.g, XPN.SavedData.ColorNumberSkill.b end,
		function(r, g, b) XPN.SavedData.ColorNumberSkill = {r = r, g = g, b = b} XPN.UpdateColors() end
	)
	
	LAM:AddButton(
		XPN.SettingsPanel,
		'XPN_Config_TestSkill',
		'Vérifier vos Préférences',
		'Cliquez sur ce bouton pour vérifier vos préférences de couleur.\r\n\r\nAssurez-vous que vous avez élargi votre fenêtre de chat ainsi vous pouvez voir le message de test.',
		function() XPN.Message(XPN.Colors.cTextSkill .. "Ceci est un |r" .. XPN.Colors.cNumberSkill .. "message de test|r" .. XPN.Colors.cTextSkill .. " de XP Notifier.|r") end,
		true,
		'N\'oubliez pas d\'agrandir votre fenêtre de chat afin que vous puissiez voir les messages de test.'
	)
	
	LAM:AddDescription(XPN.SettingsPanel, 'spacer4', '\r\n', nil)
	
	LAM:AddHeader(XPN.SettingsPanel, 'XPN_Config_Header_Debug', '|cCAB222Déboguer|r')
	
	LAM:AddCheckbox(
		XPN.SettingsPanel,
		'XPN_Config_General_DevDebug',
		'Déboguer',
		'', --'Enable this for assisting the author with troubleshooting, etc.',
		function() return XPN.DevDebug end,
		function(val) XPN.DevDebug = val end
	)
end


function XPN.SettingsPanelGerman()
	XPN.SettingsPanel = LAM:CreateControlPanel('XPN_Config', XPN.Name)

	LAM:AddHeader(XPN.SettingsPanel, 'XPN_Config_Header_General', '|cCAB222Allgemein|r')
	
	LAM:AddDropdown(
		XPN.SettingsPanel,
		'XPN_Config_General_Language',
		'Sprache',
		'',
		{ 'Deutsch', 'English (Englisch)', 'Français (Französisch)', },
		function() return "Deutsch" end,
		function(val)
			if (val == "Deutsch") then return end
			if (val == "English (Englisch)") then XPN.SavedData.Language = "en" end
			if (val == "Français (Französisch)") then XPN.SavedData.Language = "fr" end
			ReloadUI()
		end,
		true,
		'Einstellen der Sprache wird das Interface sofort neuladen.'
	)

	LAM:AddDropdown(
		XPN.SettingsPanel,
		"XPN_Config_General_WindowMode",
		"Benachrichtigungen sollen gesendet werden an...",
		"Wählen Sie, wohin Erfahrungsgewinn-Benachrichtigungen gesendet werden sollen.",
		{
			"das Chatfenster",
			"ein neues Fenster",
			"beide"
		},
		function()
			if (XPN.SavedData.Window.UseMode == 1) then return "ein neues Fenster" end
			if (XPN.SavedData.Window.UseMode == 2) then return "beide" end
			return "das Chatfenster"
		end,
		function(val)
			if (val == "das Chatfenster") then XPN.SavedData.Window.UseMode = 0 end
			if (val == "ein neues Fenster") then XPN.SavedData.Window.UseMode = 1 end
			if (val == "beide") then XPN.SavedData.Window.UseMode = 2 end
			XPN.ShowWindowPerSettings()
		end
	)
	
	LAM:AddCheckbox(
		XPN.SettingsPanel,
		'XPN_Config_General_WindowBGFade',
		'Hintergrund automatisch ausblenden',
		'',
		function() return XPN.SavedData.Window.BackgroundFade end,
		function(val) XPN.SavedData.Window.BackgroundFade = val XPN.WindowBackgroundFadePerSettings() end
	)
	
	LAM:AddSlider(
		XPN.SettingsPanel,
		'XPN_Config_Notifier_FadeTimer',
		'Verblassen Timeout',
		'Wieviele Sekunden soll es dauern bis die Nachrichten im XP Notifier Fenster nach dem letzten Zugewinn an Erfahrungspunkten ausgeblendet werden?',
		1, 600, 1,
		function() return XPN.SavedData.FadeTimer end,
		function(val) XPN.SavedData.FadeTimer = val end
	)
	
	LAM:AddCheckbox(
		XPN.SettingsPanel,
		'XPN_Config_General_WindowHide',
		'Fenster während Menüs ausblenden',
		'',
		function() return XPN.SavedData.Window.HideInMenus end,
		function(val) XPN.SavedData.Window.HideInMenus = val XPN.InterfaceUpdate() end
	)
		
	LAM:AddCheckbox(
		XPN.SettingsPanel,
		'XPN_Config_General_TrackLevelUps',
		'Immer über ein neues Level informieren',
		'',
		function() return XPN.SavedData.TrackLevelUps end,
		function(val) XPN.SavedData.TrackLevelUps = val end
	)

	--LAM:AddDescription(XPN.SettingsPanel, 'WindowHideDesc', 'Please note: if you use any add-ons that hide the compass while playing, the above setting will not work (the XP Notifier window will always be hidden).  Due to a limited add-on API, interface menu/settings detection is checking the visibility of the game compass.  If you do not use any add-ons that hide the compass during gameplay or are not using the separate XP Notifier window, you can ignore this message.', nil)
	
	LAM:AddDescription(XPN.SettingsPanel, 'spacer3', '\r\n', nil)

	LAM:AddHeader(XPN.SettingsPanel, 'XPN_Config_Header_CharacterXP', '|cCAB222Charakter XP|r')

	LAM:AddCheckbox(
		XPN.SettingsPanel,
		'XPN_Config_Notifier_WantXP',
		'Charakter XP-Gewinn',
		'',
		function() return XPN.SavedData.WantXP end,
		function(val) XPN.SavedData.WantXP = val end
	)

	LAM:AddCheckbox(
		XPN.SettingsPanel,
		'XPN_Config_Notifier_WantRepeatXP',
		'Anzeigen Anzahl von Wiederholungen',
		'', --'Shows how many repetitions it would take of the last XP gain event to level up.',
		function() return XPN.SavedData.WantRepeatXP end,
		function(val) XPN.SavedData.WantRepeatXP = val end
	)
	
	LAM:AddEditBox(
		XPN.SettingsPanel,
		'XPN_Config_Notifier_GainPrefixXP',
		'Benachrichtigung-Präfix',
		'',
		false,
		function() return XPN.SavedData.GainPrefixXP end,
		function(val) XPN.SavedData.GainPrefixXP = val end
	)
	
	LAM:AddColorPicker(
		XPN.SettingsPanel,
		'XPN_Config_Text',
		'Farbe des Textes',
		'', --'Set the color for general text in the character XP notifier.',
		function() return XPN.SavedData.ColorText.r, XPN.SavedData.ColorText.g, XPN.SavedData.ColorText.b end,
		function(r, g, b) XPN.SavedData.ColorText = {r = r, g = g, b = b} XPN.UpdateColors() end
	)
	
	LAM:AddColorPicker(
		XPN.SettingsPanel,
		'XPN_Config_Numbers',
		'Farbe der Zahl',
		'', --'Set the color for numbers in the character XP notifier.',
		function() return XPN.SavedData.ColorNumber.r, XPN.SavedData.ColorNumber.g, XPN.SavedData.ColorNumber.b end,
		function(r, g, b) XPN.SavedData.ColorNumber = {r = r, g = g, b = b} XPN.UpdateColors() end
	)

	LAM:AddButton(
		XPN.SettingsPanel,
		'XPN_Config_TestXP',
		'Überprüfen',
		'', --'Click this button to test your color preferences.\r\n\r\nMake sure you have expanded your chat window so you can see the test message.',
		function() XPN.Message(XPN.Colors.cText .. "Dies ist eine |r" .. XPN.Colors.cNumber .. "Testnachricht|r" .. XPN.Colors.cText .. " von XP Notifier.|r") end --,
		--true,
		--'Don\'t forget to expand your chat window so you can see test messages.'
	)
	
	LAM:AddDescription(XPN.SettingsPanel, 'spacer1', '\r\n', nil)
	
	LAM:AddHeader(XPN.SettingsPanel, 'XPN_Config_Header_TradeskillXP', '|cCAB222Handwerksfertigkeiten|r')

	LAM:AddCheckbox(
		XPN.SettingsPanel,
		'XPN_Config_Notifier_WantRepeatTS',
		'Anzeigen Anzahl von Wiederholungen',
		'', --'Shows how many repetitions it would take of the last tradeskill XP gain event to level up.',
		function() return XPN.SavedData.WantRepeatTS end,
		function(val) XPN.SavedData.WantRepeatTS = val end
	)	
	
	LAM:AddEditBox(
		XPN.SettingsPanel,
		'XPN_Config_Notifier_GainPrefixTS',
		'Benachrichtigung-Präfix',
		'',
		false,
		function() return XPN.SavedData.GainPrefixTS end,
		function(val) XPN.SavedData.GainPrefixTS = val end
	)
	
	for i = 1, TableLength(XPN.Skills.List) do
		if (XPN.Skills.List[i].Type == 8) then
			LAM:AddCheckbox(
				XPN.SettingsPanel,
				'XPN_Config_Notifier_Want' .. XPN.Skills.List[i].Name,
				CleanName(XPN.Skills.List[i].Name),
				'', --'Enable this to receive messages in the chat window whenever you receive ' .. CleanName(XPN.Skills.List[i].Name) .. ' experience.',
				function() return XPN.WantSkill(XPN.Skills.List[i].Name) end,
				function(val) XPN.SavedData.WantSkillID[XPN.Skills.List[i].Name] = val end
			)
		end
	end

	LAM:AddColorPicker(
		XPN.SettingsPanel,
		'XPN_Config_TextTS',
		'Farbe des Textes',
		'', --'Set the color for general text in the tradeskill notifiers.',
		function() return XPN.SavedData.ColorTextTS.r, XPN.SavedData.ColorTextTS.g, XPN.SavedData.ColorTextTS.b end,
		function(r, g, b) XPN.SavedData.ColorTextTS = {r = r, g = g, b = b} XPN.UpdateColors() end
	)
	
	LAM:AddColorPicker(
		XPN.SettingsPanel,
		'XPN_Config_NumbersTS',
		'Farbe der Zahl',
		'', --'Set the color for numbers in the tradeskill notifiers.',
		function() return XPN.SavedData.ColorNumberTS.r, XPN.SavedData.ColorNumberTS.g, XPN.SavedData.ColorNumberTS.b end,
		function(r, g, b) XPN.SavedData.ColorNumberTS = {r = r, g = g, b = b} XPN.UpdateColors() end
	)
	
	LAM:AddButton(
		XPN.SettingsPanel,
		'XPN_Config_TestTS',
		'Überprüfen',
		'', --'Click this button to test your color preferences.\r\n\r\nMake sure you have expanded your chat window so you can see the test message.',
		function() XPN.Message(XPN.Colors.cTextTS .. "Dies ist eine |r" .. XPN.Colors.cNumberTS .. "Testnachricht|r" .. XPN.Colors.cTextTS .. " von XP Notifier.|r") end --,
		--true,
		--'Don\'t forget to expand your chat window so you can see test messages.'
	)
	
	LAM:AddDescription(XPN.SettingsPanel, 'spacer2', '\r\n', nil)
	
	LAM:AddHeader(XPN.SettingsPanel, 'XPN_Config_Header_OtherSkillXP', '|cCAB222Andere Fähigkeiten|r')

	LAM:AddCheckbox(
		XPN.SettingsPanel,
		'XPN_Config_Notifier_WantRepeatSkill',
		'Anzeigen Anzahl von Wiederholungen',
		'', --'Shows how many repetitions it would take of the last skill XP gain event to level up.',
		function() return XPN.SavedData.WantRepeatSkill end,
		function(val) XPN.SavedData.WantRepeatSkill = val end
	)
	
	LAM:AddEditBox(
		XPN.SettingsPanel,
		'XPN_Config_Notifier_GainPrefixSkill',
		'Benachrichtigung-Präfix',
		'',
		false,
		function() return XPN.SavedData.GainPrefixSkill end,
		function(val) XPN.SavedData.GainPrefixSkill = val end
	)
	
	for i = 1, TableLength(XPN.Skills.List) do
		if (XPN.Skills.List[i].Type ~= 8) then
			LAM:AddCheckbox(
				XPN.SettingsPanel,
				'XPN_Config_Notifier_Want' .. XPN.Skills.List[i].Name,
				CleanName(XPN.Skills.List[i].Name),
				'', --'Enable this to receive messages in the chat window whenever you receive ' .. CleanName(XPN.Skills.List[i].Name) .. ' experience.',
				function() return XPN.WantSkill(XPN.Skills.List[i].Name) end,
				function(val) XPN.SavedData.WantSkillID[XPN.Skills.List[i].Name] = val end
			)
		end
	end

	LAM:AddColorPicker(
		XPN.SettingsPanel,
		'XPN_Config_TextSkill',
		'Farbe des Textes',
		'', --'Set the color for general text in the skill notifiers.',
		function() return XPN.SavedData.ColorTextSkill.r, XPN.SavedData.ColorTextSkill.g, XPN.SavedData.ColorTextSkill.b end,
		function(r, g, b) XPN.SavedData.ColorTextSkill = {r = r, g = g, b = b} XPN.UpdateColors() end
	)
	
	LAM:AddColorPicker(
		XPN.SettingsPanel,
		'XPN_Config_NumbersSkill',
		'Farbe der Zahl',
		'', --'Set the color for numbers in the skill notifiers.',
		function() return XPN.SavedData.ColorNumberSkill.r, XPN.SavedData.ColorNumberSkill.g, XPN.SavedData.ColorNumberSkill.b end,
		function(r, g, b) XPN.SavedData.ColorNumberSkill = {r = r, g = g, b = b} XPN.UpdateColors() end
	)
	
	LAM:AddButton(
		XPN.SettingsPanel,
		'XPN_Config_TestSkill',
		'Überprüfen',
		'', --'Click this button to test your color preferences.\r\n\r\nMake sure you have expanded your chat window so you can see the test message.',
		function() XPN.Message(XPN.Colors.cTextSkill .. "Dies ist eine |r" .. XPN.Colors.cNumberSkill .. "Testnachricht|r" .. XPN.Colors.cTextSkill .. " von XP Notifier.|r") end --,
		--true,
		--'Don\'t forget to expand your chat window so you can see test messages.'
	)
	
	LAM:AddDescription(XPN.SettingsPanel, 'spacer4', '\r\n', nil)
	
	LAM:AddHeader(XPN.SettingsPanel, 'XPN_Config_Header_Debug', '|cCAB222Debug|r')
	
	LAM:AddCheckbox(
		XPN.SettingsPanel,
		'XPN_Config_General_DevDebug',
		'Debug',
		'', --'Enable this for assisting the author with troubleshooting, etc.',
		function() return XPN.DevDebug end,
		function(val) XPN.DevDebug = val end
	)
end
